@@ -1,14 +1,15 @@
 // Copyright (c) CoSApp Team
 
-import {IJupyterWidgetRegistry} from '@jupyter-widgets/base';
-import
-  {
-    ILabShell, JupyterFrontEnd,
-    JupyterFrontEndPlugin
-  } from '@jupyterlab/application';
-import {INotebookTracker} from '@jupyterlab/notebook';
+import { IJupyterWidgetRegistry } from '@jupyter-widgets/base';
+import {
+  ILabShell,
+  JupyterFrontEnd,
+  JupyterFrontEndPlugin,
+} from '@jupyterlab/application';
+import { INotebookTracker } from '@jupyterlab/notebook';
 import * as widgetExports from './plugin';
-import {MODULE_NAME, MODULE_VERSION} from './version';
+import { BaseWidgetView } from './widgets/base/base_widget';
+import { MODULE_NAME, MODULE_VERSION } from './version';
 
 const EXTENSION_ID = 'cosapp_lab:plugin';
 
@@ -20,7 +21,7 @@ const sidecarPlugin: JupyterFrontEndPlugin<void> = {
   requires: [IJupyterWidgetRegistry, ILabShell],
   optional: [INotebookTracker],
   activate: activateWidgetExtension,
-  autoStart: true
+  autoStart: true,
 };
 
 export default sidecarPlugin;
@@ -34,15 +35,17 @@ function activateWidgetExtension(
   shell: ILabShell,
   tracker: INotebookTracker
 ): void {
-  widgetExports.SysExplorerView.shell = shell;
-  widgetExports.SysExplorerView.tracker = tracker;
-  widgetExports.GeometryViewerView.shell = shell;
-  widgetExports.GeometryViewerView.tracker = tracker;
-  widgetExports.ChartViewerView.shell = shell;
-  widgetExports.ChartViewerView.tracker = tracker;
+
+  for (const Class of Object.values(widgetExports)) {
+    if (Class.prototype instanceof BaseWidgetView) {
+      Class.shell = shell;
+      Class.tracker = tracker;
+    }
+  }
+
   registry.registerWidget({
     name: MODULE_NAME,
     version: MODULE_VERSION,
-    exports: widgetExports as any
+    exports: widgetExports as any,
   });
 }
